Brainload :: Documentation — brainload v0.3.2 documentation

# Welcome to brainload’s documentation!

Contents:

- Brainload API Documentation
  - Submodules
  - brainload.freesurferdata module
  - brainload.annotations module
  - brainload.nitools module
  - brainload.spatial module
  - brainload.meshexport module
- Brainload Example Workflows
  - Loading data for a single subject
    - Load brain mesh and morphometry data for a single subject in subject space
    - Load morphometry data for a single subject that has been mapped to a common subject

# Indices and tables

- Index
- Module Index
- Search Page